]> sigrok.org Git - libsigrok.git/blobdiff - device.c
sr: fx2lafw: Forgot to add (C) line to fx2lafw.h in recent commit.
[libsigrok.git] / device.c
index ba29adb526c4e48caa1609c994fc60cee2abadab..6b56da3a7ad7a727ef0fe56a5defb2caf4458e61 100644 (file)
--- a/device.c
+++ b/device.c
@@ -283,7 +283,7 @@ SR_API int sr_dev_probe_name_set(struct sr_dev *dev, int probenum,
  * @return SR_OK upon success, SR_ERR_ARG upon invalid arguments.
  *         If something other than SR_OK is returned, 'dev' is unchanged.
  */
-SR_API int sr_dev_trigger_clear(struct sr_dev *dev)
+SR_API int sr_dev_trigger_remove_all(struct sr_dev *dev)
 {
        struct sr_probe *p;
        unsigned int pnum; /* TODO: uint16_t? */
@@ -311,7 +311,10 @@ SR_API int sr_dev_trigger_clear(struct sr_dev *dev)
 }
 
 /**
* Add a trigger to the specified device.
  *
  * TODO: Better description.
  * TODO: Describe valid format of the 'trigger' string.
@@ -350,6 +353,8 @@ SR_API int sr_dev_trigger_set(struct sr_dev *dev, int probenum,
        g_free(p->trigger);
 
        p->trigger = g_strdup(trigger);
+       sr_dbg("dev: %s: Setting '%s' trigger for probe %d.", __func__,
+              p->trigger, probenum);
 
        return SR_OK;
 }
@@ -357,10 +362,10 @@ SR_API int sr_dev_trigger_set(struct sr_dev *dev, int probenum,
 /**
  * Determine whether the specified device has the specified capability.
  *
- * TODO: Should return int?
- *
  * @param dev Pointer to the device to be checked. Must not be NULL.
- *            The device's 'driver' field must not be NULL either.
+ *            If the device's 'driver' field is NULL (virtual device), this
+ *            function will always return FALSE (virtual devices don't have
+ *            a hardware capabilities list).
  * @param hwcap The capability that should be checked (whether it's supported
  *              by the specified device).
  *
@@ -376,7 +381,7 @@ SR_API gboolean sr_dev_has_hwcap(const struct sr_dev *dev, int hwcap)
 
        if (!dev) {
                sr_err("dev: %s: dev was NULL", __func__);
-               return FALSE; /* TODO: SR_ERR_ARG. */
+               return FALSE;
        }
 
        /*
@@ -386,14 +391,14 @@ SR_API gboolean sr_dev_has_hwcap(const struct sr_dev *dev, int hwcap)
        if (!dev->driver) {
                sr_dbg("dev: %s: dev->driver was NULL, this seems to be "
                       "a virtual device without capabilities", __func__);
-               return FALSE; /* TODO: SR_ERR_ARG. */
+               return FALSE;
        }
 
        /* TODO: Sanity check on 'hwcap'. */
 
        if (!(hwcaps = dev->driver->hwcap_get_all())) {
                sr_err("dev: %s: dev has no capabilities", __func__);
-               return FALSE; /* TODO: SR_ERR*. */
+               return FALSE;
        }
 
        for (i = 0; hwcaps[i]; i++) {
@@ -311,7 +311,10 @@ SR_API int sr_dev_trigger_clear(struct sr_dev *dev)
 
 /**
- * Add a trigger to the specified device.
+ * Add a trigger to the specified device (and the specified probe).
+ *
+ * If the specified probe of this device already has a trigger, it will
+ * be silently replaced.
  *
  * TODO: Better description.